function [betagl,betaloc,mhatgl,varb,hgl,hloc,hb,mse,biasb,imingl,iminloc] = ...
		ebbsspam(x,z,y,h1,h2,alpha,k,j1,j2,t,M1) ;
%
%
%	Finds the best bandwidth when estimating a linear functional
%	of beta (coefficients given by alpha)
%
%	Finds the "best" bandwidth for estimating a linear function
%	(given by alpha) of beta (parametric part) of a semiparametric
%	additive model (spam).  Uses EBBS to find the best bandwidth
%
%		INPUT
%	x = parametrically fitted variables
%	z = nonparametrically fitted variables
%	y = response
%	h1, h2 = limits for searching for the global bandwidth factor. 
%	(The global bandwidth for a z variable is the factor times the
%	std of that z variable.)
%	k = vector of degrees of the local polynomial fits (one component
%	per z variable) (default is vector of ones)
%	alpha = coefficient of the linear function of beta = coefficients
%	of beta (default is vector of ones)
%	j1,j2, t, and M1 are EBBS tuning parameters with default values of j1=0,
%	j2=2, t=2, and M1=20.  M1 is the number of trial bandwidth
%	factors
%	
%
%		OUTPUT:
%	betagl = betahat based on global minimizer of estimated mse
%	betaloc = betahat based on first local minimizer of est. mse
%	mhat =
%	Last edit: 9/13/97
%
if nargin < 11 ;
M1 = 20 ;
end ;

if nargin < 10 ;
t = 2 ;
end ;

if nargin < 9 ;
j2 = 3 ;
end ;

if nargin < 8 ;
j1 = 0 ;
end ;

if nargin < 7 ;
k =  ones(size(z,2),1)  ;
end ;

if nargin < 6 ;
alpha = ones(size(x,2),1) ;
end ;

if nargin < 5 ;
h2 = 2.0 ;
end ;

if nargin < 4 ;
h1 = .1 ;
end ;

n = length(z) ;

h=logspace(log10(h1),log10(h2),M1)' ;  	% Set possible bandwidths
betahatparam = zeros(M1,1) ;		% Set up storage
betahat=zeros(M1,min(size(x)));
mhat = zeros(n,M1) ;
stdz = std(z)' ;


	for j = 1:M1;			% Compute fits
	[temp,mhat(:,j),sigma2(j),var2] = fastspam(x,z,y,h(j).*stdz,k) ;
	betahat(j,:)=temp';		% Est. of beta
	betahatparam(j) = alpha'*temp ;	% Estimate of parametric fn.
					% of beta
	var(j) = alpha'*var2*alpha ;	% Est. of var. of betahatparam
	end ;


	for j = (1+j1):(M1-j2) ;	% Est. bias and mse
	H = ones(j2+j1+1,1) ;

		for tt = 2:(1+t) ;
		H = [H  h(j-j1:j+j2).^tt] ;
		end ;
		
	biascoef =  inv(H'*H) * (H'*betahatparam(j-j1:j+j2)) ;
	bias = 0 ;
		for tt=2:(1+t) ;
		bias = bias + biascoef(tt)*h(j).^tt ;
		end ;
	mse(j-j1) = bias^2 + var(j) ;
	biasb(j-j1)=bias ;
	varb(j-j1)=sigma2(j)*var(j);
	hb(j-j1)=h(j);
	betab(j-j1,:)=betahat(j,:);
	mhatb(:,j-j1) = mhat(:,j) ;
	end ;

%		"gl" means global minimizers of mse
%		"loc" means first local minimizer of mse
%

[msemin,imingl] = min(mse) ;	% find global minimizer of mse
imingl = min(imingl) ;		% choose smallest global min. if not unique

iminloc = cols(mse) ;		% begin finding first local minimizer
for j = 1:(cols(mse)-1) ;
	if (mse(j) < mse(j+1)) & (iminloc == cols(mse));
		iminloc = j ;
	end ;
end ;
hgl = hb(imingl) ;		% bandwidth that is global minimizer
hloc = hb(iminloc) ;		% bandwidth that is local minimizer

betaloc = betab(iminloc,:) ;	% betahat corresponding to hloc
betagl = betab(imingl,:) ;	% betahat corresponding to hgl

mhatgl = mhat(:,imingl) ;
